summaryrefslogtreecommitdiffstats
path: root/src/libs/engine/GraphObject.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libs/engine/GraphObject.h')
-rw-r--r--src/libs/engine/GraphObject.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/libs/engine/GraphObject.h b/src/libs/engine/GraphObject.h
index aaf20e25..8754c28a 100644
--- a/src/libs/engine/GraphObject.h
+++ b/src/libs/engine/GraphObject.h
@@ -22,7 +22,7 @@
#include <map>
#include <cstddef>
#include <cassert>
-#include "MaidObject.h"
+#include <raul/Deletable.h>
#include "raul/Path.h"
#include "raul/Atom.h"
#include "types.h"
@@ -41,13 +41,13 @@ class ObjectStore;
/** An object on the audio graph - Patch, Node, Port, etc.
*
* Each of these is a MaidObject and so can be deleted in a realtime safe
* way from anywhere, and they all have a map of metadata for clients to store
* arbitrary values in (which the engine puts no significance to whatsoever).
*
* \ingroup engine
*/
-class GraphObject : public MaidObject
+class GraphObject : public Raul::Deletable
{
public:
typedef std::map<string, Atom> MetadataMap;
@@ -41,13 +41,13 @@ class ObjectStore;
/** An object on the audio graph - Patch, Node, Port, etc.
*
- * Each of these is a MaidObject and so can be deleted in a realtime safe
+ * Each of these is a Raul::Deletable and so can be deleted in a realtime safe
* way from anywhere, and they all have a map of metadata for clients to store
* arbitrary values in (which the engine puts no significance to whatsoever).